"""
This package contains the :class:`.Actor` class as well as a
distributed variant thereof.  Actor is a high-level interface around
the lower-level :class:`panda3d.core.Character` implementation.
It loads and controls an animated character and manages the animations
playing on it.

See the :ref:`loading-actors-and-animations` page in the Programming Guide
to learn more about loading animated models.
"""
